PEP: 429 Title: Python 3.4 Release Schedule Version: $Revision$
Last-Modified: $Date$ Author: Larry Hastings <larry@hastings.org>
Status: Final Type: Informational Content-Type: text/x-rst Created:
17-Oct-2012 Python-Version: 3.4

Abstract
========

This document describes the development and release schedule for Python
3.4. The schedule primarily concerns itself with PEP-sized items.

.. Small features may be added up to the first beta release. Bugs may be
fixed until the final release, which is planned for March 2014.

Release Manager and Crew
========================

-   3.4 Release Manager: Larry Hastings
-   Windows installers: Martin v. Löwis
-   Mac installers: Ned Deily
-   Documentation: Georg Brandl

Release Schedule
================

Python 3.4 has now reached its end-of-life and has been retired. No more
releases will be made.

These are all the historical releases of Python 3.4, including their
release dates.

-   3.4.0 alpha 1: August 3, 2013
-   3.4.0 alpha 2: September 9, 2013
-   3.4.0 alpha 3: September 29, 2013
-   3.4.0 alpha 4: October 20, 2013
-   3.4.0 beta 1: November 24, 2013
-   3.4.0 beta 2: January 5, 2014
-   3.4.0 beta 3: January 26, 2014
-   3.4.0 candidate 1: February 10, 2014
-   3.4.0 candidate 2: February 23, 2014
-   3.4.0 candidate 3: March 9, 2014
-   3.4.0 final: March 16, 2014
-   3.4.1 candidate 1: May 5, 2014
-   3.4.1 final: May 18, 2014
-   3.4.2 candidate 1: September 22, 2014
-   3.4.2 final: October 6, 2014
-   3.4.3 candidate 1: February 8, 2015
-   3.4.3 final: February 25, 2015
-   3.4.4 candidate 1: December 6, 2015
-   3.4.4 final: December 20, 2015
-   3.4.5 candidate 1: June 12, 2016
-   3.4.5 final: June 26, 2016
-   3.4.6 candidate 1: January 2, 2017
-   3.4.6 final: January 17, 2017
-   3.4.7 candidate 1: July 25, 2017
-   3.4.7 final: August 9, 2017
-   3.4.8 candidate 1: January 23, 2018
-   3.4.8 final: February 4, 2018
-   3.4.9 candidate 1: July 19, 2018
-   3.4.9 final: August 2, 2018
-   3.4.10 candidate 1: March 4, 2019
-   3.4.10 final: March 18, 2019

Features for 3.4
================

Implemented / Final PEPs:

-   PEP 428, a "pathlib" module providing object-oriented filesystem
    paths
-   PEP 435, a standardized "enum" module
-   PEP 436, a build enhancement that will help generate introspection
    information for builtins
-   PEP 442, improved semantics for object finalization
-   PEP 443, adding single-dispatch generic functions to the standard
    library
-   PEP 445, a new C API for implementing custom memory allocators
-   PEP 446, changing file descriptors to not be inherited by default in
    subprocesses
-   PEP 450, a new "statistics" module
-   PEP 451, standardizing module metadata for Python's module import
    system
-   PEP 453, a bundled installer for the *pip* package manager
-   PEP 454, a new "tracemalloc" module for tracing Python memory
    allocations
-   PEP 456, a new hash algorithm for Python strings and binary data
-   PEP 3154, a new and improved protocol for pickled objects
-   PEP 3156, a new "asyncio" module, a new framework for asynchronous
    I/O

Deferred to post-3.4:

-   PEP 431, improved support for time zone databases
-   PEP 441, improved Python zip application support
-   PEP 447, support for **locallookup** metaclass method
-   PEP 448, additional unpacking generalizations
-   PEP 455, key transforming dictionary

Copyright
=========

This document has been placed in the public domain.

 .. Local Variables: mode: indented-text indent-tabs-mode: nil
sentence-end-double-space: t fill-column: 70 coding: utf-8 End:
